#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.shared.common.portlet.interfaces import ISharedContentHeaderPortletSettings
from pyams_form.interfaces.form import IInnerTabForm
from pyams_pagelet.interfaces import IPagelet
from pyams_portal.interfaces import IPortletPreviewer
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION

# import packages
from pyams_form.form import AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_portal.portlet import PortletPreviewer
from pyams_portal.zmi.portlet import PortletSettingsEditor, PortletSettingsPropertiesEditor
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from zope.interface import Interface


@pagelet_config(name='properties.html', context=ISharedContentHeaderPortletSettings, layer=IPyAMSLayer,
                permission=VIEW_SYSTEM_PERMISSION)
class SharedContentHeaderPortletSettingsEditor(PortletSettingsEditor):
    """Shared content header portlet settings editor"""

    settings = ISharedContentHeaderPortletSettings


@adapter_config(name='properties', context=(Interface, IPyAMSLayer, SharedContentHeaderPortletSettingsEditor),
                provides=IInnerTabForm)
class SharedContentHeaderPortletSettingsPropertiesEditor(PortletSettingsPropertiesEditor):
    """Shared content header portlet settings properties editor"""


@adapter_config(name='properties.json', context=(ISharedContentHeaderPortletSettings, IPyAMSLayer),
                provides=IPagelet)
class SharedContentHeaderPortletAJAXEditor(AJAXEditForm, SharedContentHeaderPortletSettingsEditor):
    """Shared content header portlet settings editor, JSON renderer"""


@adapter_config(context=(Interface, IPyAMSLayer, Interface, ISharedContentHeaderPortletSettings),
                provides=IPortletPreviewer)
@template_config(template='templates/head-preview.pt', layer=IPyAMSLayer)
class SharedContentHeaderPortletPreviewer(PortletPreviewer):
    """Shared content header portlet previewer"""
